from sqlalchemy import func, desc, or_, text, and_
from flask import current_app, request, jsonify
from apps.models import *
from apps.utils.response_code import RET
from apps.view_choose import api_address


from apps.util import verify_token


#  获取晋城市全部园区信息
@api_address.route("/DefaultAddress", methods=["POST"])
def default_address():
    req_dict = request.get_json()
    district = req_dict.get("district")  # 获取区县参数
    page = req_dict.get("page")
    perpage = req_dict.get("perpage")
    # 查询出该区县的所有园区列表
    try:
        if district == "晋城市":
            result = Induzone.query.filter_by(cate='产业园区').all()
            all_jwd = [{"id": i.id, "name": i.name, "lng": i.lng, "lat": i.lat} for i in result]
            size = len(result)
            result = Induzone.query.filter_by(cate='产业园区')
            result = result.paginate(page, perpage).items
        else:
            result = Induzone.query.filter_by(district=district, cate='产业园区').all()
            all_jwd = [{"id": i.id, "name": i.name, "lng": i.lng, "lat": i.lat} for i in result]
            size = len(result)
            result = Induzone.query.filter_by(district=district, cate='产业园区')
            result = result.paginate(page, perpage).items
        if not result:
            # 在第一条建议显示
            data = [{"name": "没有找到合适的园区！"}]
            return jsonify(code=RET.OK, msg="选址成功", data=data)

        # 遍历园区，获取详细信息
        data = {"data": [{"id": i.id,
                          "name": i.name,  # 园区名称
                          "level": i.level,  # 园区级别
                          "type": i.industry_type,  # 园区类别
                          "charge": i.charge if i.charge else "-",  # 园区负责人
                          "phone": i.phone if i.phone else "-",  # 园区电话
                          "address": i.address,  # 园区地址
                          "gdp": i.gdp,
                          "area": i.area,
                          "navigat": i.navigat,
                          # "address": i.region,  # 园区地址
                          "jwd": {"lng": i.lng, "lat": i.lat}} for i in result], "all_jwd": all_jwd, "size": size}
        if not result:
            # 在第一条建议显示
            data = [{"name": "没有找到合适的载体！"}]
        return jsonify(code=RET.OK, msg="选址成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 选址评估条件筛选
@api_address.route("/ChooseAddress", methods=["POST"])
def advice():
    req_dict = request.get_json()
    key_words = req_dict.get("key_words")  # 关键字
    industry_id = req_dict.get("industry_id")  # 所属行业选择 nid（必填）
    product = req_dict.get("product")  # 主营产品 "药" （必填）
    budget = req_dict.get('budget')  # 落地投资预算 "22" # 大于 （必填）
    preference = req_dict.get("preference")  # 选址偏好 [f,f,t,f,f,f]
    revenue = req_dict.get("revenue")  # 去年营收 "2" （非必填）
    tax = req_dict.get("tax")  # 去年税收 "1" （非必填）
    address = req_dict.get("address")  # 意向选址 （非必填）

    page = req_dict.get("page")
    perpage = req_dict.get("perpage")
    if not any([key_words, product, budget, preference, revenue, tax, address]):
        return jsonify(code=RET.PARAMERR, msg="无有效参数！")
    try:
        if key_words:
            zone = Induzone.query.filter(
                and_(
                    Induzone.district == address if address and address != '晋城市' else text(''),
                    Induzone.navigat.like('%{}%'.format(product)) if product else text(''),
                    Induzone.invest_power < float(budget) if budget else text(''),
                    Induzone.cate == "产业园区",
                    Induzone.tax < tax if tax else text('')
                )).filter(
                or_(
                    Induzone.name.like("%" + key_words + "%") if key_words else text(''),
                    Induzone.level.like("%" + key_words + "%") if key_words else text(''),
                    Induzone.industry_type.like("%" + key_words + "%") if key_words else text(''),
                    Induzone.charge.like("%" + key_words + "%") if key_words else text(''),
                    Induzone.address.like("%" + key_words + "%") if key_words else text('')
            ))
        else:
            zone = Induzone.query.filter(
                Induzone.district == address if address and address != '晋城市' else text(''),
                    Induzone.navigat.like('%{}%'.format(product)) if product else text(''),
                    Induzone.invest_power < float(budget) if budget else text(''),
                    Induzone.cate == "产业园区",
                    Induzone.tax < tax if tax else text('')
                )
        if industry_id:
            # indu = Industry.query.filter_by(nid=industry_id).first()
            indu = IndustryChain.query.filter_by(id=industry_id).first()
            if not indu:
                return jsonify(code=RET.DATAERR, msg="参数错误")
            # 获取产业名称
            industry_name = indu.industry_name
            # 根据产业名称查询园区
            zone = Induzone.query.filter(or_(Induzone.navigat.like("%{}%".format(industry_name)),
                                             Induzone.navigator.like("%{}%".format(industry_name))))

        if preference[0] == "true":  # 如果有政府扶持力度 --- 政策数的打分
            zone = zone.order_by(Induzone.policy_point.desc())
        if preference[1] == "true":  # 产业聚集度 --- 产业的打分
            zone = zone.outerjoin(CompanyIndustryPoint, Induzone.name == CompanyIndustryPoint.district).filter(
                CompanyIndustryPoint.f_type == industry_id).order_by(CompanyIndustryPoint.point.desc()).all()
        if preference[2] == "true":  # 园区配套服务 ----园区的学校，商业街，宾馆打分
            zone = zone.order_by(Induzone.mall_point.desc(), Induzone.hotel_point.desc(), Induzone.school_point.desc())

        if preference[3] == "true":  # 生活配套服务
            zone = zone.order_by(Induzone.live_point.desc())
        if preference[4] == "true":  # 交通 -----交通打分
            zone = zone.order_by(Induzone.traffic_point.desc())
        size = zone.count()
        result = zone.paginate(page, perpage).items
        zone = zone.all()
        all_jwd = [{"id": i.id, "name": i.name, "lng": i.lng, "lat": i.lat} for i in zone]
        data = {"data": [{"id": i.id,
                          "name": i.name,  # 园区名称
                          "level": i.level,  # 园区级别
                          "type": i.industry_type,  # 园区类别
                          "charge": i.charge if i.charge else "-",  # 园区负责人
                          "phone": i.phone if i.phone else "-",  # 园区电话
                          "address": i.address,  # 园区地址
                          "jwd": {"lng": i.lng, "lat": i.lat}} for i in result], "all_jwd": all_jwd, "size": size}
        if not result:
            # 在第一条建议显示
            data = [{"name": "没有找到合适的园区！"}]
        return jsonify(code=RET.OK, msg="选址成功", data=data)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")


# 获取筛选条件的行业
@api_address.route("/DownList", methods=["GET"])
def downlist():  # 一级二级行业分类
    try:
        industry = IndustryChain.query.filter_by(status=1).all()
        data = [{
            "name": i.industry_name,
            "id": i.id,
        } for i in industry]
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="数据库错误")
    return jsonify(code=RET.OK, msg="查找成功", data=data)